Welcome to Grascii's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents

   README
   language
   interpretation
   gsearch
   dephrase
   dictionary
   configuration
   similarity

.. toctree::
   :maxdepth: 2
   :caption: Reference

   CHANGELOG
   API <reference/modules>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
